==> kdeclarative5-5.116.0-1-x86_64.pkg.tar.zst: usr/lib/cmake/KF5Declarative/KF5DeclarativeTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::Declarative" for configuration ""
set_property(TARGET KF5::Declarative APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::Declarative PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt5::Quick;KF5::I18n;KF5::KIOWidgets;KF5::IconThemes"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5Declarative.so.5.116.0"
  IMPORTED_SONAME_NOCONFIG "libKF5Declarative.so.5"
  )

list(APPEND _cmake_import_check_targets KF5::Declarative )
list(APPEND _cmake_import_check_files_for_KF5::Declarative "${_IMPORT_PREFIX}/lib/libKF5Declarative.so.5.116.0" )

# Import target "KF5::QuickAddons" for configuration ""
set_property(TARGET KF5::QuickAddons APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::QuickAddons PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n;KF5::Declarative;KF5::ConfigGui"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5QuickAddons.so.5.116.0"
  IMPORTED_SONAME_NOCONFIG "libKF5QuickAddons.so.5"
  )

list(APPEND _cmake_import_check_targets KF5::QuickAddons )
list(APPEND _cmake_import_check_files_for_KF5::QuickAddons "${_IMPORT_PREFIX}/lib/libKF5QuickAddons.so.5.116.0" )

# Import target "KF5::CalendarEvents" for configuration ""
set_property(TARGET KF5::CalendarEvents APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::CalendarEvents PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5CalendarEvents.so.5.116.0"
  IMPORTED_SONAME_NOCONFIG "libKF5CalendarEvents.so.5"
  )

list(APPEND _cmake_import_check_targets KF5::CalendarEvents )
list(APPEND _cmake_import_check_files_for_KF5::CalendarEvents "${_IMPORT_PREFIX}/lib/libKF5CalendarEvents.so.5.116.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> kdeclarative-5.78.0-1-x86_64.pkg.tar.zst: usr/lib/cmake/KF5Declarative/KF5DeclarativeTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::Declarative" for configuration ""
set_property(TARGET KF5::Declarative APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::Declarative PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt5::Quick;KF5::I18n;KF5::KIOWidgets;KF5::IconThemes"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5Declarative.so.5.78.0"
  IMPORTED_SONAME_NOCONFIG "libKF5Declarative.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::Declarative )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::Declarative "${_IMPORT_PREFIX}/lib/libKF5Declarative.so.5.78.0" )

# Import target "KF5::QuickAddons" for configuration ""
set_property(TARGET KF5::QuickAddons APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::QuickAddons PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n;KF5::Declarative;KF5::ConfigGui"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5QuickAddons.so.5.78.0"
  IMPORTED_SONAME_NOCONFIG "libKF5QuickAddons.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::QuickAddons )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::QuickAddons "${_IMPORT_PREFIX}/lib/libKF5QuickAddons.so.5.78.0" )

# Import target "KF5::CalendarEvents" for configuration ""
set_property(TARGET KF5::CalendarEvents APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::CalendarEvents PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5CalendarEvents.so.5.78.0"
  IMPORTED_SONAME_NOCONFIG "libKF5CalendarEvents.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::CalendarEvents )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::CalendarEvents "${_IMPORT_PREFIX}/lib/libKF5CalendarEvents.so.5.78.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
